@@ -243,3 +243,48 @@ class TestInstafailingTerminalReporter(object):
             result.stdout.fnmatch_lines([
                 "collected 0 items / 1 errors",
             ])
+
+    def test_print_stacktrace_once_with_pdb(self, testdir, request, option):
+        test_file = testdir.makepyfile(
+            """
+            def test_func():
+                assert 0
+            """
+        )
+
+        args = option.args
+        args.append(" --pdb %s" % test_file)
+
+        child = testdir.spawn_pytest(' '.join(args))
+        child.expect('>+ traceback >+')
+
+        assert 'E       assert 0' not in child.before
+
+        child.expect('(Pdb)')
+        child.sendeof()
+        if child.isalive():
+            child.wait()
+
+    def test_xfail_unexpected_success(self, testdir, option):
+        testdir.makepyfile(
+            """
+            import pytest
+            @pytest.mark.xfail
+            def test_func():
+                pass
+            """
+        )
+        result = testdir.runpytest(*option.args)
+        if option.verbose:
+            result.stdout.fnmatch_lines([
+                "test_xfail_unexpected_success.py:2: test_func XPASS"
+            ])
+        elif option.quiet:
+            result.stdout.fnmatch_lines([
+                "X"
+            ])
+        else:
+            result.stdout.fnmatch_lines([
+                "test_xfail_unexpected_success.py X"
+            ])
+        assert "INTERNALERROR" not in result.stdout.str()
